@@ -23,6 +23,14 @@ RewriteEngine on
 RewriteBase /
 """
 
+nginx_rules = b"""
+location / {
+    #root {0};
+    index index.html;
+    try_files $uri $uri.html $uri/index.html;
+}
+"""
+
 @after
 class PrettyURLProcessor(Processor):
     def process(self, documents, resources):
@@ -45,4 +53,8 @@ class PrettyURLProcessor(Processor):
 
         htaccess.content += apache_redirects
 
+        nginx = Resource(path='.nginx',
+                         content=nginx_rules)
+        resources.append(nginx)
+
         return documents, resources
